autowisp.database.data_model.observing_session module — AutoWISP documentation

# autowisp.database.data_model.observing_session module

## Class Inheritance Diagram

Define the observing session table for the pipeline

class autowisp.database.data_model.observing_session.ObservingSession(**kwargs)

  Bases: `DataModelBase`

  The table describing the observing session

  camera
  camera_id

    The id of the camera

  end_time_utc

    The end time of the observing session in UTC

  id

    A unique identifier for each row.

  images
  label

    Unique label assigned to the observing session

  mount
  mount_id

    The id of the mount

  notes

    The notes provided for the observing session

  observatory
  observatory_id

    The id of the observatory

  observer
  observer_id

    The id of the observer

  start_time_utc

    The start time of the observing session in UTC

  target
  target_id

    The id of the target

  telescope
  telescope_id

    The id of the telescope

  timestamp

    When record was last changed